/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the Qt Charts module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:GPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 or (at your option) any later version
** approved by the KDE Free Qt Foundation. The licenses are as published by
** the Free Software Foundation and appearing in the file LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "datasource.h"
#include <QtCharts/QXYSeries>
#include <QtCharts/QAreaSeries>
#include <QtQuick/QQuickView>
#include <QtQuick/QQuickItem>
#include <QtCore/QDebug>
#include <QtCore/QtMath>

QT_CHARTS_USE_NAMESPACE

Q_DECLARE_METATYPE(QAbstractSeries *)
Q_DECLARE_METATYPE(QAbstractAxis *)

DataSource::DataSource(QQuickView *appViewer, QObject *parent) :
    QObject(parent),
    m_appViewer(appViewer)
{
    qRegisterMetaType<QAbstractSeries*>();
    qRegisterMetaType<QAbstractAxis*>();
    for (int i = 0; i < 3; i++)
    {
        m_data.append(QVector<QPointF>());
    }
    //ADDED
    for (int i = 0; i < 3; i++)
    {
        m_data[i].resize(3600);
    }
    for (int i = 0; i < 3; i++) {
        for(int j=0; j < 3600; j++) {
            qreal y = qSin(3.14159265358979 / 50 * j) + 0.5 + (qreal) rand() / (qreal) RAND_MAX + i;
            m_data[i][j]=QPointF(j, y);
        }
    }
    m_timeCnt=3600;
}

void DataSource::update(QAbstractSeries *series, const int dataId)
{
    if (series) {
        QXYSeries *xySeries = static_cast<QXYSeries *>(series);

        if (dataId == 0)
        {
            generateData();
        }
        // Use replace instead of clear + append, it's optimized for performance
        xySeries->replace(m_data.at(dataId));
    }
}

void DataSource::generateData()
{
    for (int i = 0; i < 3; i++) {
        for(int j=1; j < 3600; j++) {
            m_data[i][j-1].setX(m_data[i][j].x());
            m_data[i][j-1].setY(m_data[i][j].y());
        }
        qreal y = qSin(3.14159265358979 / 50 * m_timeCnt) + 0.5 + (qreal) rand() / (qreal) RAND_MAX + i;
        m_data[i][3599].setX(m_timeCnt);
        m_data[i][3599].setY(y);
    }

/*    for (int i = 0; i < 3; i++)
    {
        if (m_data[i].count() > 3600)
        {
            m_data[i].removeFirst();
        }
        qreal y = qSin(3.14159265358979 / 50 * m_timeCnt) + 0.5 + (qreal) rand() / (qreal) RAND_MAX + i;
        m_data[i].append(QPointF(m_timeCnt, y));
    }
    */

    m_timeCnt++;
}
